aboutsummaryrefslogtreecommitdiff
path: root/include/ImageUtils.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'include/ImageUtils.hpp')
-rw-r--r--include/ImageUtils.hpp10
1 files changed, 8 insertions, 2 deletions
diff --git a/include/ImageUtils.hpp b/include/ImageUtils.hpp
index 58eb197..f5f757e 100644
--- a/include/ImageUtils.hpp
+++ b/include/ImageUtils.hpp
@@ -3,7 +3,13 @@
#include "Path.hpp"
namespace QuickMedia {
- // Works with jpg, png and gif files
- bool image_get_resolution(const Path &path, int *width, int *height);
+ enum class ImageType {
+ JPG,
+ PNG,
+ GIF
+ };
+
+ // Works with jpg, png and gif files. |image_type| can be NULL
+ bool image_get_resolution(const Path &path, int *width, int *height, ImageType *image_type = nullptr);
bool is_image_ext(const char *ext);
} \ No newline at end of file